# transpara-py-sdk
installation 


pip3 install transpara-py-sdk==0.9git pu.0


usage

check /tests/tests.py
https://github.com/transpara/transpara-py-sdk/blob/main/tests/tests.py

(debug_elapsed and log_middleware both have async versions)